# MoCapLib
MoCapLib: Library for Motion Capture data processing and analysis

## Description
The aim of this repository is to provide a simple Python-based library for motion capture data processing and analysis.

## Installation
MoCapLib can be installed from [PyPI](https://pypi.org/project/mocaplib/) using ```pip``` on Python>=3.7.

```bash
pip install mocaplib
```

## Usage
Currently, MoCapLib is under heavy development.

## Installation of BTK (Microsoft Windows x64 platforms) for C3D file parsing
- [Conda-forge](https://anaconda.org/conda-forge/btk) (find the [details](https://github.com/Biomechanical-ToolKit/BTKCore/issues/28#issuecomment-572571063))
- [PyPI](https://pypi.org/project/pyBTK/)

## Dependencies
- [NumPy](https://numpy.org/)
- [SciPy](https://www.scipy.org/)

## License
[MIT](https://choosealicense.com/licenses/mit/)
